====================
bodhi-dequeue-stable
====================

Synopsis
========

``bodhi-dequeue-stable``


Description
===========

``bodhi-dequeue-stable`` changes all updates with request: batched to request: stable.


Options
=======

``--help``

    Display help text.

``--version``

    Report the Bodhi version and exit.


Help
====

If you find bugs in bodhi (or in the man page), please feel free to file a bug report or a pull
request:

    https://github.com/fedora-infra/bodhi

Bodhi's documentation is available online: https://bodhi.fedoraproject.org/docs
